==> haskell-status-notifier-item-0.3.1.0-194-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-status-notifier-item.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 status-notifier-item
version:              0.3.1.0
visibility:           public
id:                   status-notifier-item-0.3.1.0-Ju6LvfcjPC3LvtB1L75MnT
key:                  status-notifier-item-0.3.1.0-Ju6LvfcjPC3LvtB1L75MnT
license:              BSD-3-Clause
copyright:            2018 Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/status-notifier-item#readme
synopsis:
    A wrapper over the StatusNotifierItem/libappindicator dbus specification

description:
    Please see the README on Github at <https://github.com/IvanMalison/status-notifier-item#readme>

category:             Desktop
abi:                  c5fb217bf7c0f27b14b2b0ac463d66a6
exposed:              True
exposed-modules:
    StatusNotifier.Host.Service StatusNotifier.Item.Client
    StatusNotifier.Item.Service StatusNotifier.TH StatusNotifier.Util
    StatusNotifier.Watcher.Client StatusNotifier.Watcher.Constants
    StatusNotifier.Watcher.Service StatusNotifier.Watcher.Signals

hidden-modules:       Paths_status_notifier_item
import-dirs:          /usr/lib/ghc-9.4.8/site-local/status-notifier-item-0.3.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/status-notifier-item-0.3.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/status-notifier-item-0.3.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-status-notifier-item
hs-libraries:         HSstatus-notifier-item-0.3.1.0-Ju6LvfcjPC3LvtB1L75MnT
depends:
    base-4.17.2.1 byte-order-0.1.3.1-JexXqhCfGbEyQPAV1ajOK
    bytestring-0.11.5.3
    bytestring-to-vector-0.3.0.1-FE1MkQ33XrZEy6I1pccUUO
    containers-0.6.7 dbus-1.3.1-Ixlt0oVuydFGkf3eFOAVqG filepath-1.4.2.2
    hslogger-1.3.1.2-8umnl6dHSprEwJOaTsVrLQ
    lens-5.2.3-EqD4LSjkO4yUdDVMPM2Ph template-haskell-2.19.0.0
    text-2.0.2 transformers-0.5.6.2
    vector-0.13.1.0-GCmMsLcrTyFGJ15LkY6umX

haddock-interfaces:
    /usr/share/doc/haskell-status-notifier-item/html/status-notifier-item.haddock

haddock-html:         /usr/share/doc/haskell-status-notifier-item/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-status-notifier-item-0.3.1.0-195-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-status-notifier-item.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 status-notifier-item
version:              0.3.1.0
visibility:           public
id:                   status-notifier-item-0.3.1.0-8U5bv1couaN8Rq5AmWWGA8
key:                  status-notifier-item-0.3.1.0-8U5bv1couaN8Rq5AmWWGA8
license:              BSD-3-Clause
copyright:            2018 Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/status-notifier-item#readme
synopsis:
    A wrapper over the StatusNotifierItem/libappindicator dbus specification

description:
    Please see the README on Github at <https://github.com/IvanMalison/status-notifier-item#readme>

category:             Desktop
abi:                  f9f0e22b29de711f2f8e9a3e0e51dea0
exposed:              True
exposed-modules:
    StatusNotifier.Host.Service StatusNotifier.Item.Client
    StatusNotifier.Item.Service StatusNotifier.TH StatusNotifier.Util
    StatusNotifier.Watcher.Client StatusNotifier.Watcher.Constants
    StatusNotifier.Watcher.Service StatusNotifier.Watcher.Signals

hidden-modules:       Paths_status_notifier_item
import-dirs:          /usr/lib/ghc-9.4.8/site-local/status-notifier-item-0.3.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/status-notifier-item-0.3.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/status-notifier-item-0.3.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-status-notifier-item
hs-libraries:         HSstatus-notifier-item-0.3.1.0-8U5bv1couaN8Rq5AmWWGA8
depends:
    base-4.17.2.1 byte-order-0.1.3.1-H8gqAsZAYKQFfsd4DbCrrD
    bytestring-0.11.5.3
    bytestring-to-vector-0.3.0.1-FE1MkQ33XrZEy6I1pccUUO
    containers-0.6.7 dbus-1.3.1-JVWhIyEWawZFwQtvEgKadU filepath-1.4.2.2
    hslogger-1.3.1.2-8umnl6dHSprEwJOaTsVrLQ
    lens-5.2.3-45KLP8DrieZ6NfgM752wdp template-haskell-2.19.0.0
    text-2.0.2 transformers-0.5.6.2
    vector-0.13.1.0-GCmMsLcrTyFGJ15LkY6umX

haddock-interfaces:
    /usr/share/doc/haskell-status-notifier-item/html/status-notifier-item.haddock

haddock-html:         /usr/share/doc/haskell-status-notifier-item/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
